@@ -27,12 +27,14 @@
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-clone-options.h>
 #include <libgit2-glib/ggit-commit.h>
+#include <libgit2-glib/ggit-commit-parents.h>
 #include <libgit2-glib/ggit-config-entry.h>
 #include <libgit2-glib/ggit-config.h>
 #include <libgit2-glib/ggit-cred.h>
 #include <libgit2-glib/ggit-cred-plaintext.h>
 #include <libgit2-glib/ggit-diff-delta.h>
 #include <libgit2-glib/ggit-diff-file.h>
+#include <libgit2-glib/ggit-diff-format-email-options.h>
 #include <libgit2-glib/ggit-diff.h>
 #include <libgit2-glib/ggit-diff-hunk.h>
 #include <libgit2-glib/ggit-diff-line.h>
@@ -52,7 +54,6 @@
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-oid.h>
 #include <libgit2-glib/ggit-patch.h>
-#include <libgit2-glib/ggit-push.h>
 #include <libgit2-glib/ggit-ref.h>
 #include <libgit2-glib/ggit-reflog-entry.h>
 #include <libgit2-glib/ggit-reflog.h>
@@ -64,6 +65,7 @@
 #include <libgit2-glib/ggit-signature.h>
 #include <libgit2-glib/ggit-status-options.h>
 #include <libgit2-glib/ggit-submodule.h>
+#include <libgit2-glib/ggit-submodule-update-options.h>
 #include <libgit2-glib/ggit-tag.h>
 #include <libgit2-glib/ggit-transfer-progress.h>
 #include <libgit2-glib/ggit-tree-builder.h>
@@ -71,10 +73,8 @@
 #include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-types.h>
 
-#ifdef GIT_SSH
 #include <libgit2-glib/ggit-cred-ssh-key-from-agent.h>
 #include <libgit2-glib/ggit-cred-ssh-interactive.h>
-#endif
 
 #endif
 
